@@ -5,8 +5,10 @@ import shutil
 import time
 from urllib.error import URLError
 import zipfile
+import json
 
 import wget
+import requests
 
 from r2env.exceptions import PackageManagerException
 from r2env.tools import load_json_file, git_fetch, git_clean, print_console, ERROR, exit_if_not_exists, host_distname
@@ -19,7 +21,7 @@ class PackageManager:
     DOWNLOAD_URL = "https://github.com/radareorg/radare2/releases/download/"
 
     def __init__(self, r2env_path):
-        self._packages = self._load_profiles()
+        self._packages = self._load_profiles(r2env_path)
         self._r2env_path = r2env_path
 
     def get_package_path(self, package_name):
@@ -38,13 +40,106 @@ class PackageManager:
         return res
 
     @staticmethod
-    def _load_profiles():
-        filename = os.path.join(os.path.dirname(__file__), 'config', 'profiles.json')
+    def _load_profiles(r2env_path):
+        filename = os.path.join(r2env_path, 'profiles.json')
+        # if profiles.json doesn't exist, generate it now
+        if not os.path.exists(filename):
+            print_console(f"NOTE: {filename} does not exist. Generating it now.")
+            PackageManager.update_radare2_profiles(r2env_path)
         profiles = load_json_file(filename)
         if not profiles:
             raise PackageManagerException("No profiles configured.")
         return profiles
 
+    @staticmethod
+    def update_radare2_profiles(r2env_path):
+        gh_release_info_req = requests.get(
+            "https://api.github.com/repos/radareorg/radare2/releases",
+            {"headers": ["X-GitHub-Api-Version: 2022-11-28", "Accept: application/vnd.github+json"]},
+            timeout=10  # 10-second timeout for API request
+        )
+        gh_release_info_req.raise_for_status()  # raise an error if the request got a bad return code
+        gh_release_info = gh_release_info_req.json()
+        radare2_versions = [{'id': 'git', 'packages': {}}]  # include the git version by default
+        for release in gh_release_info:
+            version = {'id': release['tag_name'], 'packages': {}}
+            # generate a list of downloadable assets for this release that r2env can use
+            for asset in release['assets']:
+                # note: you're about to see 100 lines of hackery to deal with inconsistent naming schemes
+                # the goal is to include as many valid assets as is reasonable without including any that are not valid
+                # separate file extension
+                asset_name, asset_ext = os.path.splitext(asset['name'])
+
+                # normalize 'seperators' before splitting into components
+                asset_ref = asset_name.replace('_', '-').split('-')
+
+                # filter out things like r2ios_sdk and r2blob
+                if asset_ref[0] != 'radare2':
+                    continue
+
+                # Some assets don't have the version number in the name, which breaks the following processing.
+                # None of them are of interest anyway, so just skip them.
+                if release['tag_name'] not in asset_ref:
+                    continue
+
+                # remove the beginning 'radare2'
+                asset_ref.remove('radare2')
+
+                # we don't need to care about the release id when checking, so remove it
+                asset_ref.remove(release['tag_name'])
+
+                # once "radare2" and the version number have been removed from asset_ref,
+                # if all that's left matches a filter, save it.
+                _VERSION_FILTERS = {
+                    '.zip': {  # used for Windows builds among other things
+                        'w32': [['w32']],
+                        'w64': [['w64']]
+                    },
+                    '.deb': {
+                        'deb_i386': [['i386']],
+                        'deb_x64': [['amd64']]
+                    },
+                    '.pkg': {  # macOS bundle
+                        'mac_arm64': [['m1']],
+                        'mac_x64': [[], ['amd64'], ['x64'], ['macos']]
+                    }
+                }
+
+                if asset_ext in _VERSION_FILTERS:
+                    for platform, refs in _VERSION_FILTERS[asset_ext].items():
+                        if asset_ref in refs:
+                            version['packages'][platform] = asset['name']
+                            break
+
+            radare2_versions.append(version)
+
+        profiles = {
+            'r2frida': {
+                'source': 'https://github.com/nowsecure/r2frida',
+                'versions': [{'id': 'git', 'packages': {}}]
+            },
+            'r2dec': {
+                'source': 'https://github.com/wargio/r2dec-js',
+                'versions': [{'id': 'git', 'packages': {}}]
+            },
+            'r2ghidra': {
+                'source': 'https://github.com/radareorg/r2ghidra',
+                'versions': [{'id': 'git', 'packages': {}}]
+            },
+            'r0': {
+                'source': 'https://github.com/radareorg/r0',
+                'versions': [{'id': 'git', 'packages': {}}]
+            },
+            'radare2': {
+                'source': 'https://github.com/radareorg/radare2',
+                'versions': radare2_versions[::-1]
+            }
+        }
+        if not os.path.isdir(r2env_path):
+            os.makedirs(r2env_path)
+        with open(os.path.join(r2env_path, 'profiles.json'), 'w', encoding='utf-8') as f:
+            json.dump(profiles, f)
+
     def install_package(self, profile, version, use_meson, use_dist):
         log_path = os.path.join(self._r2env_path, self.LOG_DIR)
         timestamp = round(time.monotonic() * 1000)
@@ -190,7 +285,7 @@ class PackageManager:
     @staticmethod
     def _build_using_acr(source_path, dst_path, logfile, r2env_path):
         """Only works in Unix systems"""
-        if host_distname() in "w64":
+        if host_distname() is not None and host_distname() in "w64":
             raise PackageManagerException("acr is not supported on Windows platform. Use meson instead.")
         exit_if_not_exists(['make'])
         print_console("[-] Building package using acr...")
